#include <SSD1306.h>
#include <OLEDDisplay.h>
#include "esp_system.h"
#include <Wire.h>
#include <WiFi.h>
#include <WiFiUdp.h>
#include <Adafruit_PWMServoDriver.h>
                    
#define SSID "**********"          // 無線LANアクセスポイントのSSID
#define PASS "**********"          // パスワード
#define PULSE_MIN 0  // this is the 'minimum' pulse length count (out of 4096)
#define PULSE_MAX 2400  // this is the 'maximum' pulse length count (out of 4096)
#define BUZZER_PIN 25
#define R_PORT 9000

SSD1306 display(0x3c,5 , 4); // /SSD1306インスタンスの作成（I2Cアドレス,SDA,SCL
// called this way, it uses the default address 0x40
Adafruit_PWMServoDriver pwm = Adafruit_PWMServoDriver();
WiFiServer server(80);
WiFiUDP udp;

float atones[37]={
    130.813, 138.591, 146.832, 155.563, 164.814, 174.614,
    184.997, 195.998, 207.652, 220.000, 233.082, 246.942,
    261.626, 277.183, 293.665, 311.127, 329.628, 349.228,
    369.994, 391.995, 415.305, 440.000, 466.164, 493.883,
    523.251, 554.365, 587.330, 622.254, 659.255, 698.456,
    739.989, 783.991, 830.609, 880.000, 932.328, 987.767,
    0
};

String tlabels[37]={
  "C3","C#3|Db3","D3","D#3|Eb3","E3","F3","F#3|Gb3","G3","G#3|Ab3","A3","A#3|Bb3","B3",
  "C4","C#4|Db4","D4","D#4|Eb4","E4","F4","F#4|Gb4","G4","G#4|Ab4","A4","A#4|Bb4","B4",
  "C5","C#5|Db5","D5","D#5|Eb5","E5","F5","F#5|Gb5","G5","G#5|Ab5","A5","A#5|Bb5","B5",
  "PAUSE"
};

float fdurs[16]={0,0.333,0.666,1.333,2.666,5.333,1.5,3,6,12,24,1,2,4,8,16};

String dlabels[16]={
    "未定","１６分３連符","８分3連符","４分３連符","２分3連符","全３連符","付点１６分",
    "付点８分","付点４分","付点２分","付点全","１６分","８分","4分","２分","全"
};

String alabels[53]={
  "C3:0",  "C#3:1","Db3:1", "D3:2", "D#3:3", "Eb3:3", "E3:4", "F3:5", "F#3:6", "Gb3:6", "G3:7", "G#3:8", "Ab3:8", "A3:9","A#3:10", "Bb3:10","B3:11",
  "C4:12","C#4:13","Db4:13","D4:14","D#4:15","Eb4:15","E4:16","F4:17","F#4:18","Gb4:18","G4:19","G#4:20","Ab4:20","A4:21","A#4:22","Bb4:22","B4:23",
  "C5:24","C#5:25","Db5:25","D5:26","D#5:27","Eb5:27","E5:28","F5:29","F#5:30","Gb5:30","G5:31","G#5:32","Ab5:32","A5:33","A#5:34","Bb5:34","B5:35",
  "PAUSE:36"
};

String klabels[13]={
  "C/Am",        // 0: C, D, E, F, G, A, B
  "G/Em [#1]",   // 1: C, D, E, F#, G, A, B
  "D/Bm [#2]",   // 2: C#, D, E, F#, G, A, B
  "A/F#m [#3]",  // 3: C#, D, E, F#, G#, A, B
  "E/C#m [#4]",  // 4: C#, D#, E, F#, G#, A, B
  "B/G#m [#5]",  // 5: C#, D#, E, F#, G#, A#, B
  "F#/D#m [#6]", // 6: C#, D#, E#, F#, G#, A#, B
  "Db/Bbm [b5]", // 7: C, Db, Eb, F, Gb, Ab, Bb
  "Ab/Fm [b4]",  // 8: C, Db, Eb, F, G, Ab, Bb
  "Eb/Cm [b3]",  // 9: C, D, Eb, F, G, Ab, Bb
  "Bb/Gm [b2]",  // 10:C, D, Eb, F, G, A, Bb
  "F/Dm [b1]",   // 11:C, D, E, F, G, A, Bb
  "Select Song"
};

String lip;
String msg;
String title="LAMP SW ON !";
String swmode[2]={"OFF","ON"};

int nk=12;
int count=0;
int brt1=90;
int brt2=180;
int brt3=180;
int intro=0;
int kybrd=0;
int xmode=0;
int tempo=200;

int getNum(String str){
  int x=36;
  for (int i=0; i<53; i++){
    int num,len;
    String str0,str1,str2;
    str0=alabels[i];
    len=str0.length();
    num=str0.indexOf(":");
    str1=str0.substring(0,num);
    str2=str0.substring(num+1,len); 
    if (str==str1) x=str2.toInt();
  }
  return x;
}

void player(int cn){
  count++;
  tempo=200;
  float fdur=3;
  msg=String(count)+": "+tlabels[cn]+" ("+String(fdur)+")";
  drawLcd(msg);
  if (cn<36){
    int col=cn % 7 +1;
    int bin[8][3]={ {0,0,0}, {0,0,1}, {0,1,0}, {0,1,1}, {1,0,0}, {1,0,1}, {1,1,0}, {1,1,1}};
  
    ledWrite(0,bin[col][0]*brt1);
    ledWrite(1,bin[col][1]*brt2);
    ledWrite(2,bin[col][2]*brt3);
  
    ledcWriteTone(1,atones[cn]);
    delay(fdur*tempo);
    ledcWriteTone(1,0);
  } 
  ledWrite(0,0);
  ledWrite(1,0);
  ledWrite(2,0);
}

void mld(String str,int dur){
  count++;
  int cn=getNum(str);
  float fdur=fdurs[cn];
  msg=String(count)+": "+tlabels[cn]+" ("+String(dur)+")";
  drawLcd(msg);
  if (cn<36){
    int col=cn % 7 +1;
    int bin[8][3]={ {0,0,0}, {0,0,1}, {0,1,0}, {0,1,1}, {1,0,0}, {1,0,1}, {1,1,0}, {1,1,1}};
  
    ledWrite(0,bin[col][0]*brt1);
    ledWrite(1,bin[col][1]*brt2);
    ledWrite(2,bin[col][2]*brt3);

    ledcWriteTone(1,atones[cn]);
    delay(dur*tempo);
    ledcWriteTone(1,0);
    ledWrite(0,0);
    ledWrite(1,0);
    ledWrite(2,0);
  } else {
    delay(dur*tempo);
  }
}

void preparing(){
  drawLcd("START");
  delay(2000);
  ledWrite(0,brt1);
  ledWrite(1,brt2*0);
  ledWrite(2,brt3*0);
  delay(2000);
  ledWrite(0,brt1*0);
  ledWrite(1,brt2);
  ledWrite(2,brt3*0);
  count=0;
  nk=12; title="";
}

void drawLcd(String s){
  display.init();    //ディスプレイを初期化
  display.setFont(ArialMT_Plain_10);    //フォントを設定
  display.drawString(0, 0, lip);
  display.drawString(0,10, title);
  display.drawString(0,20 ,"INTRO MODE="+swmode[intro]);
  display.drawString(0,30,klabels[nk]);
  display.drawString(0,40 ,s);
  display.display();   //指定された情報を描画
}

void setup(){
  Serial.begin(9600);
  WiFi.mode(WIFI_STA);                    // 無線LANをSTAモードに設定
  WiFi.begin(SSID,PASS);                  // 無線LANアクセスポイントへ接続
  while(WiFi.status() != WL_CONNECTED){   // 接続に成功するまで待つ
    delay(500);                           // 待ち時間処理
  }
  lip=WiFi.localIP().toString();
  Serial.println();
  Serial.println(lip);
  display.init();    //ディスプレイを初期化
  display.setFont(ArialMT_Plain_10);    //フォントを設定
  pwm.begin();
  pwm.setPWMFreq(1600); // This is the maximum PWM frequency
  ledcSetup(1,12000, 8);
  ledcAttachPin(BUZZER_PIN,1);
  for( int i = 0; i <3; i++ ) {
    ledWrite(i,0);
  }
  server.begin();
  udp.begin(R_PORT);  // UDP通信御開始
  preparing();
}

void loop(){
  char buf[21];
  int len,num;                                // 文字列長を示す整数型変数を定義
  memset(buf, 0, 20);                     // 文字列変数bufの初期化(40バイト)
  len = udp.parsePacket();                // 受信パケット長を変数lenに代入
  if(len==0) return;                      // 未受信のときはloop()の先頭に戻る
  udp.read(buf, 20);                      // 受信文字列を変数bufに格納する
  Serial.println(buf);                    // シリアルモニタに表示
  String str=buf;
  xmode=str.toInt();
  if (xmode<100) player(xmode);
  if (xmode==101) playSongA();
  if (xmode==102) playSongB();
  if (xmode==103) playSongC();
  if (xmode==104) playSongD();
  if (xmode==105) playSongE();
  if (xmode==106) playSongF();
  if (xmode==200) intro=0;
  if (xmode==201) intro=1;
}

void ledWrite( int n, int power ) {
  power = map( power, 0, 255, PULSE_MIN, PULSE_MAX );  // powerを256段階に変換
  pwm.setPWM( n, 0, power );  // LED 点灯
}

void playSongA() {
  //うれしいひなまつり
  title="HINAMATSURI";
  tempo=250;
  nk=9;
  mld("G4",2);        //   1
  mld("G4",2);        //   2
  mld("G4",2);        //   3
  mld("F4",2);        //   4
  mld("G4",2);        //   5
  mld("G4",2);        //   6
  mld("C5",2);        //   7
  mld("Ab4",2);       //   8
  mld("G4",2);        //   9
  mld("G4",2);        //  10
  mld("Ab4",2);       //  11
  mld("Ab4",2);       //  12
  mld("G4",6);;       //  13
  mld("PAUSE",2);     //  14
  if (intro==0){  
    mld("Eb4",2);     //  15
    mld("Eb4",2);     //  16
    mld("Eb4",2);     //  17
    mld("D4",2);      //  18
    mld("Eb4",2);     //  19
    mld("Eb4",2);     //  20
    mld("G4",2);      //  21
    mld("Eb4",2);     //  22
    mld("D4",2);      //  23
    mld("D4",2);      //  24
    mld("Eb4",2);     //  25
    mld("D4",2);      //  26
    mld("C4",6);      //  27
    mld("PAUSE",2);   //  28
    mld("C5",4);      //  29
    mld("C5",2);      //  30
    mld("D5",2);      //  31
    mld("C5",2);      //  32
    mld("Ab4",1);     //  33
    mld("G4",1);      //  34
    mld("Eb4",2);     //  35
    mld("Eb4",2);     //  36
    mld("G4",2);      //  37
    mld("G4",2);      //  38
    mld("C5",2);      //  39
    mld("Ab4",2);     //  40
    mld("G4",6);      //  41
    mld("PAUSE",2);   //  42
    mld("Eb4",4);     //  43
    mld("D4",2);      //  44
    mld("C4",2);      //  45
    mld("D4",2);      //  46
    mld("Eb4",2);     //  47
    mld("G4",2);      //  48
    mld("C5",2);      //  49
    mld("Ab4",2);     //  50
    mld("G4",2);      //  51
    mld("Eb4",2);     //  52
    mld("D4",2);      //  53
    mld("C4",6);      //  54
    mld("PAUSE",2);   //  55
  }
  drawLcd("End of melody");
  preparing();
}

void playSongB(){
  // なつぞら 
  title="NATSUZORA";
  tempo=150;
  nk=2;
  mld("D4",4);        //   1
  mld("F#4",4);       //   2
  mld("A4",4);        //   3
  mld("G4",4);        //   4
  mld("F#4",4);       //   5
  mld("E4",4);        //   6
  mld("G4",4);        //   7
  mld("F#4",4);       //   8
  mld("D4",4);        //   9
  mld("F#4",4);       //  10
  mld("E4",6);        //  11
  mld("D4",2);        //  12
  mld("D4",12);       //  13
if (intro==0){     
    mld("PAUSE",4);   //  14
    mld("A3",2);      //  15
    mld("A3",2);      //  16
    mld("A3",2);      //  17
    mld("A3",2);      //  18
    mld("A3",2);      //  19
    mld("A3",2);      //  20
    mld("A3",2);      //  21
    mld("A3",2);      //  22
    mld("B3",2);      //  23
    mld("C#4",2);     //  24
    mld("D4",2);      //  25
    mld("E4",2);      //  26
    mld("C#4",4);     //  27
    mld("PAUSE",4);   //  28
    mld("B3",2);      //  29
    mld("D4",2);      //  30
    mld("G4",2);      //  31
    mld("F#4",4);     //  32
    mld("A3",2);      //  33
    mld("E4",2);      //  34
    mld("D4",2);      //  35
    mld("D4",6);      //  36
    mld("C#4",2);     //  37
    mld("C#4",4);     //  38
    mld("PAUSE",4);   //  39
    mld("A3",2);      //  40
    mld("A3",2);      //  41
    mld("A3",2);      //  42
    mld("A3",2);      //  43
    mld("A3",2);      //  44
    mld("A3",2);      //  45
    mld("A3",2);      //  46
    mld("A3",2);      //  47
    mld("B3",2);      //  48
    mld("C#4",2);     //  49
    mld("D4",2);      //  50
    mld("E4",2);      //  51
    mld("C#4",4);     //  52
    mld("PAUSE",4);   //  53
    mld("B3",2);      //  54
    mld("D4",2);      //  55
    mld("G4",2);      //  56
    mld("F#4",4);     //  57
    mld("A3",2);      //  58
    mld("E4",2);      //  59
    mld("D4",2);      //  60
    mld("D4",12);     //  61
    mld("PAUSE",4);   //  62
    mld("B3",4);      //  63
    mld("D4",4);      //  64
    mld("E4",4);      //  65
    mld("C#4",1);     //  66
    mld("B4",1);      //  67
    mld("A3",2);      //  68
    mld("B3",4);      //  69
    mld("B3",2);      //  70
    mld("D4",2);      //  71
    mld("E4",4);      //  72
    mld("PAUSE",2);   //  73
    mld("F#4",2);     //  74
    mld("F#4",4);     //  75
    mld("E4",2);      //  76
    mld("D4",2);      //  77
    mld("E4",4);      //  78
    mld("PAUSE",2);   //  79
    mld("F#4",2);     //  80
    mld("G4",4);      //  81
    mld("F#4",2);     //  82
    mld("E4",2);      //  83
    mld("F#4",4);     //  84
    mld("PAUSE",4);   //  85
    mld("A3",4);      //  86
    mld("D4",4);      //  87
    mld("E4",4);      //  88
    mld("C#4",1);     //  89
    mld("B3",1);      //  90
    mld("A3",2);      //  91
    mld("B3",4);      //  92
    mld("B3",2);      //  93
    mld("D4",2);      //  94
    mld("E4",4);      //  95
    mld("PAUSE",2);   //  96
    mld("F#4",2);     //  97
    mld("G4",4);      //  98
    mld("F#4",4);     //  99
    mld("E4",4);      // 100
    mld("D4",4);      // 101
    mld("C#4",2);     // 102
    mld("PAUSE",2);   // 103
    mld("C#4",4);     // 104
    mld("D4",4);      // 105
    mld("E4",4);      // 106
    mld("D4",4);      // 107
    mld("F#4",4);     // 108
    mld("A4",4);      // 109
    mld("G4",4);      // 110
    mld("F#4",4);     // 111
    mld("E4",4);      // 112
    mld("G4",4);      // 113
    mld("F#4",4);     // 114
    mld("D4",4);      // 115
    mld("F#4",4);     // 116
    mld("E4",6);      // 117
    mld("D4",2);      // 118
    mld("D4",12);     // 119
    mld("PAUSE",4);   // 120
    mld("D4",4);      // 121
    mld("F#4",4);     // 122
    mld("A4",4);      // 123
    mld("G4",4);      // 124
    mld("F#4",4);     // 125
    mld("E4",4);      // 126
    mld("G4",4);      // 127
    mld("F#4",4);     // 128
    mld("D4",4);      // 129
    mld("F#4",4);     // 130
    mld("E4",6);      // 131
    mld("D4",2);      // 132
    mld("D4",12);     // 133
    mld("PAUSE",4);   // 134
  }
  drawLcd("End of melody");
  preparing();
}

void playSongC(){
  // スカーレット
  title="SCARLET";
  tempo=150;
  nk=2;
  mld("F#4",2);       //   1
  mld("G4",2);        //   2
  mld("F#4",2);       //   3
  mld("E4",4);        //   4
  mld("F#4",2);       //   5
  mld("D4",4);        //   6
  mld("A4",12);       //   7
  mld("PAUSE",4);     //   8
  mld("B4",6);        //   9
  mld("PAUSE",1);     //  10
  mld("G4",6);        //  11
  mld("PAUSE",1);     //  12
  mld("G4",2);        //  13
  mld("F#4",4);       //  14
  mld("E4",4);        //  15
  mld("D4",4);        //  16
  mld("E4",4);        //  17
  if (intro==0){     
    mld("F#4",2);     //  18
    mld("G4",2);      //  19
    mld("F#4",2);     //  20
    mld("E4",4);      //  21
    mld("F#4",2);     //  22
    mld("D4",4);      //  23
    mld("A4",12);     //  24
    mld("PAUSE",4);   //  25
    mld("B4",6);      //  26
    mld("PAUSE",1);   //  27
    mld("G4",6);      //  28
    mld("PAUSE",1);   //  29
    mld("G4",2);      //  30
    mld("F#4",4);     //  31
    mld("E4",4);      //  32
    mld("G4",4);      //  33
    mld("F#4",4);     //  34
    mld("PAUSE",4);   //  35
    mld("A4",2);      //  36
    mld("F#4",2);     //  37
    mld("F#4",2);     //  38
    mld("E4",2);      //  39
    mld("E4",2);      //  40 
    mld("F#4",2);     //  41
    mld("B3",12);     //  42
    mld("PAUSE",8);   //  43
    mld("A4",2);      //  44
    mld("F#4",2);     //  45
    mld("F#4",2);     //  46
    mld("E4",2);      //  47
    mld("E4",2);      //  48
    mld("F#4",2);     //  49
    mld("B3",12);     //  50
    mld("C#4",4);     //  51
    mld("C#4",12);    //  52
    mld("PAUSE",12);  //  53
    mld("A3",1);      //  54
    mld("PAUSE",1);   //  55
    mld("D4",10);     //  56
    mld("E4",1);      //  57
    mld("D4",3);      //  58
    mld("F#4",4);     //  69
    mld("E4",6);      //  60
    mld("A4",2);      //  61
    mld("B4",2);      //  62
    mld("C#5",2);     //  63
    mld("D5",4);      //  64
    mld("B4",8);      //  65
    mld("A4",2);      //  66
    mld("G4",4);      //  67
    mld("A4",6);      //  68
    mld("PAUSE",1);   //  69
    mld("A4",1);      //  70
    mld("A#4",2);     //  71
    mld("B4",2);      //  72
    mld("C#5",3);     //  73
    mld("D5",7);      //  74
    mld("PAUSE",2);   //  75
    mld("F#4",2);     //  76
    mld("G4",2);      //  77
    mld("A4",2);      //  78
    mld("B4",10);     //  79
    mld("A4",3);      //  80
    mld("D5",3);      //  81
    mld("F#4",2);     //  82
    mld("G#4",8);     //  83
    mld("G#4",6);     //  84
    mld("G#4",1);     //  85
    mld("B4",3);      //  86
    mld("C#5",2);     //  87
    mld("B4",2);      //  88
    mld("A4",4);      //  89
    mld("PAUSE",2);   //  90
    mld("A3",1);      //  91
    mld("PAUSE",1);   //  92
    mld("D4",10);     //  93
    mld("D4",2);      //  94
    mld("E4",1);      //  95
    mld("D4",3);      //  96
    mld("F#4",4);     //  97
    mld("E4",6);      //  98
    mld("PAUSE",2);   //  99
    mld("A4",2);      // 100
    mld("B4",2);      // 101
    mld("C#5",2);     // 102
    mld("D5",4);      // 103
    mld("B4",8);      // 104
    mld("B4",2);      // 105
    mld("C#5",4);     // 106
    mld("D5",12);     // 107
    mld("PAUSE",4);   // 108
    mld("A4",3);      // 109
    mld("A4",1);      // 110
    mld("A4",2);      // 111
    mld("D5",2);      // 112
    mld("G4",8);      // 113
    mld("PAUSE",2);   // 114
    mld("G4",2);      // 115
    mld("G4",2);      // 116
    mld("F#4",1);     // 117
    mld("F#4",1);     // 118
    mld("G4",2);      // 119
    mld("F#4",1);     // 120
    mld("F#4",1);     // 121
    mld("E4",2);      // 122
    mld("D4",2);      // 123
    mld("A4",2);      // 124
    mld("A4",1);      // 125
    mld("D5",3);      // 126
    mld("G4",8);      // 127
    mld("PAUSE",8);   // 128
    mld("G4",2);      // 129
    mld("G4",2);      // 130
    mld("G4",2);      // 131
    mld("G4",1);      // 132
    mld("F#4",1);     // 133
    mld("G4",2);      // 134
    mld("F#4",2);     // 135
    mld("E4",4);      // 136
    mld("D4",8);      // 137
    mld("A4",4);      // 138
    mld("A4",2);      // 139
    mld("D5",2);      // 140
    mld("G4",8);      // 141
    mld("PAUSE",2);   // 142
    mld("G4",2);      // 143
    mld("G4",2);      // 144
    mld("F#4",2);     // 145
    mld("G4",2);      // 146
    mld("F#4",2);     // 147
    mld("E4",2);      // 148
    mld("D4",2);      // 149
    mld("A4",4);      // 150
    mld("A4",2);      // 151
    mld("D5",2);      // 152
    mld("G4",16);     // 153
    mld("G4",2);      // 154
    mld("G4",2);      // 155
    mld("G4",2);      // 156
    mld("G4",1);      // 157
    mld("F#4",1);     // 158
    mld("G4",2);      // 159
    mld("F#4",2);     // 160
    mld("E4",4);      // 161
    mld("D4",16);     // 162
  }
  drawLcd("End of melody");
  preparing();
}

void playSongD() {
  // 花
  title="HANA";
  tempo=250;
  nk=1;
  mld("D4",3);        //   1
  mld("D4",1);        //   2
  mld("G4",2);        //   3
  mld("PAUSE",1);     //   4
  mld("G4",1);        //   5
  mld("A4",1);        //   6
  mld("G4",1);        //   7
  mld("F#4",1);       //   8
  mld("E4",1);        //   9
  mld("D4",4);        //  10
  mld("B3",1);        //  11
  mld("D4",1);        //  12
  mld("G4",1);        //  13
  mld("A4",1);        //  14
  mld("B4",2);        //  15
  mld("D5",2);        //  16
  mld("A4",6);        //  17
  if (intro==0){  
    mld("PAUSE",2);   //  18
    mld("D4",3);      //  19
    mld("D4",1);      //  20
    mld("G4",2);      //  21
    mld("PAUSE",1);   //  22
    mld("G4",1);      //  23
    mld("A4",1);      //  24
    mld("G4",1);      //  25
    mld("F#4",1);     //  26
    mld("E4",1);      //  27
    mld("D4",4);      //  28
    mld("A4",3);      //  29
    mld("A4",1);      //  30
    mld("A4",2);      //  31
    mld("B4",2);      //  32
    mld("G4",6);      //  33
    mld("PAUSE",2);   //  34
    mld("D5",3);      //  35
    mld("D5",1);      //  36
    mld("D5",3);      //  37
    mld("PAUSE",1);   //  38
    mld("B4",1);      //  39
    mld("C5",3);      //  40
    mld("C5",1);      //  41
    mld("C5",2);      //  42
    mld("PAUSE",1);   //  43
    mld("A4",1);      //  44
    mld("B4",4);      //  45
    mld("E4",2);      //  46
    mld("A4",2);      //  47
    mld("D4",6);      //  48
    mld("PAUSE",2);   //  49
    mld("D4",3);      //  50
    mld("D4",1);      //  51
    mld("G4",2);      //  52
    mld("G4",2);      //  53
    mld("A4",1);      //  54
    mld("G4",1);      //  55
    mld("F#4",1);     //  56
    mld("E4",1);      //  57
    mld("D4",4);      //  58
    mld("A4",2);      //  59
    mld("A4",1);      //  60
    mld("B4",1);      //  61
    mld("C5",2);      //  62
    mld("A4",2);      //  63
    mld("G4",6);      //  64
    mld("PAUSE",2);   //  65
  }
  drawLcd("End of melody");
  preparing();
}

void playSongE(){
  // 牧場の朝
  title="MAKIBA NO AS";
  tempo=250;  
  mld("G4",2);      // 1
  mld("F#4",1);     // 2
  mld("G4",1);      // 3
  mld("A4",2);      // 4
  mld("B4",2);      // 5
  mld("A4",3);      // 6
  mld("A4",1);      // 7
  mld("A4",2);      // 8
  mld("PAUSE",2);   // 9
  mld("B4",2);      // 10
  mld("B4",1);      // 11
  mld("C#5",1);     // 12
  mld("D5",2);      // 13
  mld("E5",2);      // 14
  mld("A4",4);      // 15
  if (intro==0){  
    mld("PAUSE",2); // 16
    mld("A4",2);    // 17
    mld("B4",3);    // 18
    mld("B4",1);    // 19
    mld("G4",2);    // 20
    mld("B4",2);    // 21
    mld("D5",4);    // 22
    mld("A4",2);    // 23
    mld("F#4",2);   // 24
    mld("A4",3);    // 25
    mld("B4",1);    // 26
    mld("A4",2);    // 27
    mld("F#4",2);   // 28
    mld("E4",4);    // 29
    mld("PAUSE",4); // 30
    mld("D4",3);    // 31
    mld("D4",1);    // 32
    mld("D4",2);    // 33
    mld("E4",2);    // 34
    mld("F#4",1);   // 35
    mld("A4",1);    // 36
    mld("F#4",1);   // 37
    mld("E4",1);    // 38
    mld("D4",2);    // 39
    mld("F#4",2);   // 40
    mld("A4",4);    // 41
    mld("B4",2);    // 42
    mld("B4",2);    // 43
    mld("A4",4);    // 42
    mld("PAUSE",2); // 43
    mld("A4",2);    // 44
    mld("D5",4);    // 45
    mld("A4",2);    // 46
    mld("A4",2);    // 47
    mld("B4",2);    // 48
    mld("B4",2);    // 49
    mld("A4",2);    // 50
    mld("F#4",2);   // 51
    mld("A4",4);    // 52
    mld("E4",3);    // 53
    mld("E4",1);    // 54
    mld("D4",4);    // 55
    mld("PAUSE",2); // 56
    mld("D4",2);    // 57
    mld("D4",3);    // 58
    mld("E4",1);    // 59
    mld("F#4",1);   // 60
    mld("A4",1);    // 61
    mld("B4",2);    // 62
    mld("D5",4);    // 63
    mld("A4",4);    // 64
    mld("F#4",4);   // 65
    mld("E4",4);    // 66
    mld("D4",6);    // 67
    mld("PAUSE",2); // 68
  }
  drawLcd("End of melody");
  preparing();
}

void playSongF(){
  // 知床旅情
  title="SHRETOKO-RYOJO";
  tempo=150;
  mld("G3",4);      // 1
  mld("C4",8);      // 2
  mld("E4",4);      // 3
  mld("G4",8);      // 4
  mld("C5",4);      // 5
  mld("C5",4);      // 6
  mld("A4",4);      // 7
  mld("C5",4);      // 8
  mld("G4",12);     // 9
  mld("E4",4);      // 10
  mld("F4",4);      // 11
  mld("E4",4);      // 12
  mld("D4",8);      // 13
  mld("G4",4);      // 14
  mld("E4",4);      // 15
  mld("D4",4);      // 16
  mld("E4",4);      // 17
  mld("C4",8);      // 18
  if (intro==0){  
    mld("G3",4);    // 19
    mld("C4",8);    // 20
    mld("E4",4);    // 21
    mld("G4",8);    // 22
    mld("C5",4);    // 23
    mld("C5",4);    // 24
    mld("A4",4);    // 25
    mld("C5",4);    // 26
    mld("G4",12);   // 27
    mld("E4",4);    // 28
    mld("F4",4);    // 29
    mld("E4",4);    // 30
    mld("D4",8);    // 31
    mld("G4",4);    // 32
    mld("G3",8);    // 33
    mld("D4",4);    // 34
    mld("C4",12);   // 35
    mld("D4",4);    // 36
    mld("D4",4);    // 37
    mld("D4",4);    // 38
    mld("D4",4);    // 39
    mld("C4",4);    // 40
    mld("D4",4);    // 41
    mld("E4",12);   // 42
    mld("G4",12);   // 43
    mld("A4",4);    // 44
    mld("A4",4);    // 45
    mld("A4",4);    // 46
    mld("A4",4);    // 47
    mld("F4",4);    // 48
    mld("A4",4);    // 49
    mld("C5",12);   // 50
    mld("C5",8);    // 51
    mld("D5",4);    // 53
    mld("C5",4);    // 54
    mld("A4",4);    // 55
    mld("G4",8);    // 56
    mld("C5",4);    // 57
    mld("E4",8);    // 58
    mld("A4",4);    // 59
    mld("G4",12);   // 60
    mld("E4",4);    // 61
    mld("F4",4);    // 62
    mld("E4",4);    // 63
    mld("D4",4);    // 64
    mld("G3",4);    // 65
    mld("D4",4);    // 66
    mld("C4",16);   // 67
  }
  drawLcd("End of melody");
  preparing();
}
